import { z } from 'zod';

/**
 * Schema for validating environment variables used by the SettleMint SDK.
 * Defines validation rules and types for configuration values like URLs,
 * access tokens, workspace names, and service endpoints.
 */
declare const DotEnvSchema: z.ZodObject<{
    /** Base URL of the SettleMint platform instance */
    SETTLEMINT_INSTANCE: z.ZodDefault<z.ZodString>;
    /** Application access token for authenticating with SettleMint services */
    SETTLEMINT_ACCESS_TOKEN: z.ZodOptional<z.ZodString>;
    /** @internal */
    SETTLEMINT_PERSONAL_ACCESS_TOKEN: z.ZodOptional<z.ZodString>;
    /** Unique name of the workspace */
    SETTLEMINT_WORKSPACE: z.ZodOptional<z.ZodString>;
    /** Unique name of the application */
    SETTLEMINT_APPLICATION: z.ZodOptional<z.ZodString>;
    /** Unique name of the blockchain network */
    SETTLEMINT_BLOCKCHAIN_NETWORK: z.ZodOptional<z.ZodString>;
    /** Chain ID of the blockchain network */
    SETTLEMINT_BLOCKCHAIN_NETWORK_CHAIN_ID: z.ZodOptional<z.ZodString>;
    /** Unique name of the blockchain node (should have a private key for signing transactions) */
    SETTLEMINT_BLOCKCHAIN_NODE: z.ZodOptional<z.ZodString>;
    /** JSON RPC endpoint for the blockchain node */
    SETTLEMINT_BLOCKCHAIN_NODE_JSON_RPC_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Unique name of the blockchain node or load balancer */
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER: z.ZodOptional<z.ZodString>;
    /** JSON RPC endpoint for the blockchain node or load balancer */
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER_JSON_RPC_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Unique name of the Hasura instance */
    SETTLEMINT_HASURA: z.ZodOptional<z.ZodString>;
    /** Endpoint URL for the Hasura GraphQL API */
    SETTLEMINT_HASURA_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Admin secret for authenticating with Hasura */
    SETTLEMINT_HASURA_ADMIN_SECRET: z.ZodOptional<z.ZodString>;
    /** Database connection URL for Hasura */
    SETTLEMINT_HASURA_DATABASE_URL: z.ZodOptional<z.ZodString>;
    /** Unique name of The Graph instance */
    SETTLEMINT_THEGRAPH: z.ZodOptional<z.ZodString>;
    /** Array of endpoint URLs for The Graph subgraphs */
    SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS: z.ZodEffects<z.ZodOptional<z.ZodArray<z.ZodString, "many">>, string[] | undefined, unknown>;
    /** Default The Graph subgraph to use */
    SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH: z.ZodOptional<z.ZodString>;
    /** Unique name of the Smart Contract Portal instance */
    SETTLEMINT_PORTAL: z.ZodOptional<z.ZodString>;
    /** GraphQL endpoint URL for the Portal */
    SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** REST endpoint URL for the Portal */
    SETTLEMINT_PORTAL_REST_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Unique name of the HD private key */
    SETTLEMINT_HD_PRIVATE_KEY: z.ZodOptional<z.ZodString>;
    /** Unique name of the accessible private key */
    SETTLEMINT_ACCESSIBLE_PRIVATE_KEY: z.ZodOptional<z.ZodString>;
    /** Unique name of the MinIO instance */
    SETTLEMINT_MINIO: z.ZodOptional<z.ZodString>;
    /** Endpoint URL for MinIO */
    SETTLEMINT_MINIO_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Access key for MinIO authentication */
    SETTLEMINT_MINIO_ACCESS_KEY: z.ZodOptional<z.ZodString>;
    /** Secret key for MinIO authentication */
    SETTLEMINT_MINIO_SECRET_KEY: z.ZodOptional<z.ZodString>;
    /** Unique name of the IPFS instance */
    SETTLEMINT_IPFS: z.ZodOptional<z.ZodString>;
    /** API endpoint URL for IPFS */
    SETTLEMINT_IPFS_API_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Pinning service endpoint URL for IPFS */
    SETTLEMINT_IPFS_PINNING_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Gateway endpoint URL for IPFS */
    SETTLEMINT_IPFS_GATEWAY_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Unique name of the custom deployment */
    SETTLEMINT_CUSTOM_DEPLOYMENT: z.ZodOptional<z.ZodString>;
    /** Endpoint URL for the custom deployment */
    SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Unique name of the Blockscout instance */
    SETTLEMINT_BLOCKSCOUT: z.ZodOptional<z.ZodString>;
    /** GraphQL endpoint URL for Blockscout */
    SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** UI endpoint URL for Blockscout */
    SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT: z.ZodOptional<z.ZodString>;
    /** Name of the new project being created */
    SETTLEMINT_NEW_PROJECT_NAME: z.ZodOptional<z.ZodString>;
    /** The log level to use */
    SETTLEMINT_LOG_LEVEL: z.ZodDefault<z.ZodEnum<["debug", "info", "warn", "error", "none"]>>;
}, "strip", z.ZodTypeAny, {
    SETTLEMINT_INSTANCE: string;
    SETTLEMINT_LOG_LEVEL: "error" | "info" | "warn" | "debug" | "none";
    SETTLEMINT_ACCESS_TOKEN?: string | undefined;
    SETTLEMINT_PERSONAL_ACCESS_TOKEN?: string | undefined;
    SETTLEMINT_WORKSPACE?: string | undefined;
    SETTLEMINT_APPLICATION?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NETWORK?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NETWORK_CHAIN_ID?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_JSON_RPC_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER_JSON_RPC_ENDPOINT?: string | undefined;
    SETTLEMINT_HASURA?: string | undefined;
    SETTLEMINT_HASURA_ENDPOINT?: string | undefined;
    SETTLEMINT_HASURA_ADMIN_SECRET?: string | undefined;
    SETTLEMINT_HASURA_DATABASE_URL?: string | undefined;
    SETTLEMINT_THEGRAPH?: string | undefined;
    SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS?: string[] | undefined;
    SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH?: string | undefined;
    SETTLEMINT_PORTAL?: string | undefined;
    SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT?: string | undefined;
    SETTLEMINT_PORTAL_REST_ENDPOINT?: string | undefined;
    SETTLEMINT_HD_PRIVATE_KEY?: string | undefined;
    SETTLEMINT_ACCESSIBLE_PRIVATE_KEY?: string | undefined;
    SETTLEMINT_MINIO?: string | undefined;
    SETTLEMINT_MINIO_ENDPOINT?: string | undefined;
    SETTLEMINT_MINIO_ACCESS_KEY?: string | undefined;
    SETTLEMINT_MINIO_SECRET_KEY?: string | undefined;
    SETTLEMINT_IPFS?: string | undefined;
    SETTLEMINT_IPFS_API_ENDPOINT?: string | undefined;
    SETTLEMINT_IPFS_PINNING_ENDPOINT?: string | undefined;
    SETTLEMINT_IPFS_GATEWAY_ENDPOINT?: string | undefined;
    SETTLEMINT_CUSTOM_DEPLOYMENT?: string | undefined;
    SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT?: string | undefined;
    SETTLEMINT_NEW_PROJECT_NAME?: string | undefined;
}, {
    SETTLEMINT_INSTANCE?: string | undefined;
    SETTLEMINT_ACCESS_TOKEN?: string | undefined;
    SETTLEMINT_PERSONAL_ACCESS_TOKEN?: string | undefined;
    SETTLEMINT_WORKSPACE?: string | undefined;
    SETTLEMINT_APPLICATION?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NETWORK?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NETWORK_CHAIN_ID?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_JSON_RPC_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER_JSON_RPC_ENDPOINT?: string | undefined;
    SETTLEMINT_HASURA?: string | undefined;
    SETTLEMINT_HASURA_ENDPOINT?: string | undefined;
    SETTLEMINT_HASURA_ADMIN_SECRET?: string | undefined;
    SETTLEMINT_HASURA_DATABASE_URL?: string | undefined;
    SETTLEMINT_THEGRAPH?: string | undefined;
    SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS?: unknown;
    SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH?: string | undefined;
    SETTLEMINT_PORTAL?: string | undefined;
    SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT?: string | undefined;
    SETTLEMINT_PORTAL_REST_ENDPOINT?: string | undefined;
    SETTLEMINT_HD_PRIVATE_KEY?: string | undefined;
    SETTLEMINT_ACCESSIBLE_PRIVATE_KEY?: string | undefined;
    SETTLEMINT_MINIO?: string | undefined;
    SETTLEMINT_MINIO_ENDPOINT?: string | undefined;
    SETTLEMINT_MINIO_ACCESS_KEY?: string | undefined;
    SETTLEMINT_MINIO_SECRET_KEY?: string | undefined;
    SETTLEMINT_IPFS?: string | undefined;
    SETTLEMINT_IPFS_API_ENDPOINT?: string | undefined;
    SETTLEMINT_IPFS_PINNING_ENDPOINT?: string | undefined;
    SETTLEMINT_IPFS_GATEWAY_ENDPOINT?: string | undefined;
    SETTLEMINT_CUSTOM_DEPLOYMENT?: string | undefined;
    SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT?: string | undefined;
    SETTLEMINT_NEW_PROJECT_NAME?: string | undefined;
    SETTLEMINT_LOG_LEVEL?: "error" | "info" | "warn" | "debug" | "none" | undefined;
}>;
/**
 * Type definition for the environment variables schema.
 */
type DotEnv = z.infer<typeof DotEnvSchema>;
/**
 * Partial version of the environment variables schema where all fields are optional.
 * Useful for validating incomplete configurations during development or build time.
 */
declare const DotEnvSchemaPartial: z.ZodObject<{
    SETTLEMINT_INSTANCE: z.ZodOptional<z.ZodDefault<z.ZodString>>;
    SETTLEMINT_ACCESS_TOKEN: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_PERSONAL_ACCESS_TOKEN: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_WORKSPACE: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_APPLICATION: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKCHAIN_NETWORK: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKCHAIN_NETWORK_CHAIN_ID: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKCHAIN_NODE: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKCHAIN_NODE_JSON_RPC_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER_JSON_RPC_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_HASURA: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_HASURA_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_HASURA_ADMIN_SECRET: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_HASURA_DATABASE_URL: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_THEGRAPH: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS: z.ZodOptional<z.ZodEffects<z.ZodOptional<z.ZodArray<z.ZodString, "many">>, string[] | undefined, unknown>>;
    SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_PORTAL: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_PORTAL_REST_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_HD_PRIVATE_KEY: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_ACCESSIBLE_PRIVATE_KEY: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_MINIO: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_MINIO_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_MINIO_ACCESS_KEY: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_MINIO_SECRET_KEY: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_IPFS: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_IPFS_API_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_IPFS_PINNING_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_IPFS_GATEWAY_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_CUSTOM_DEPLOYMENT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKSCOUT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_NEW_PROJECT_NAME: z.ZodOptional<z.ZodOptional<z.ZodString>>;
    SETTLEMINT_LOG_LEVEL: z.ZodOptional<z.ZodDefault<z.ZodEnum<["debug", "info", "warn", "error", "none"]>>>;
}, "strip", z.ZodTypeAny, {
    SETTLEMINT_INSTANCE?: string | undefined;
    SETTLEMINT_ACCESS_TOKEN?: string | undefined;
    SETTLEMINT_PERSONAL_ACCESS_TOKEN?: string | undefined;
    SETTLEMINT_WORKSPACE?: string | undefined;
    SETTLEMINT_APPLICATION?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NETWORK?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NETWORK_CHAIN_ID?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_JSON_RPC_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER_JSON_RPC_ENDPOINT?: string | undefined;
    SETTLEMINT_HASURA?: string | undefined;
    SETTLEMINT_HASURA_ENDPOINT?: string | undefined;
    SETTLEMINT_HASURA_ADMIN_SECRET?: string | undefined;
    SETTLEMINT_HASURA_DATABASE_URL?: string | undefined;
    SETTLEMINT_THEGRAPH?: string | undefined;
    SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS?: string[] | undefined;
    SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH?: string | undefined;
    SETTLEMINT_PORTAL?: string | undefined;
    SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT?: string | undefined;
    SETTLEMINT_PORTAL_REST_ENDPOINT?: string | undefined;
    SETTLEMINT_HD_PRIVATE_KEY?: string | undefined;
    SETTLEMINT_ACCESSIBLE_PRIVATE_KEY?: string | undefined;
    SETTLEMINT_MINIO?: string | undefined;
    SETTLEMINT_MINIO_ENDPOINT?: string | undefined;
    SETTLEMINT_MINIO_ACCESS_KEY?: string | undefined;
    SETTLEMINT_MINIO_SECRET_KEY?: string | undefined;
    SETTLEMINT_IPFS?: string | undefined;
    SETTLEMINT_IPFS_API_ENDPOINT?: string | undefined;
    SETTLEMINT_IPFS_PINNING_ENDPOINT?: string | undefined;
    SETTLEMINT_IPFS_GATEWAY_ENDPOINT?: string | undefined;
    SETTLEMINT_CUSTOM_DEPLOYMENT?: string | undefined;
    SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT?: string | undefined;
    SETTLEMINT_NEW_PROJECT_NAME?: string | undefined;
    SETTLEMINT_LOG_LEVEL?: "error" | "info" | "warn" | "debug" | "none" | undefined;
}, {
    SETTLEMINT_INSTANCE?: string | undefined;
    SETTLEMINT_ACCESS_TOKEN?: string | undefined;
    SETTLEMINT_PERSONAL_ACCESS_TOKEN?: string | undefined;
    SETTLEMINT_WORKSPACE?: string | undefined;
    SETTLEMINT_APPLICATION?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NETWORK?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NETWORK_CHAIN_ID?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_JSON_RPC_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER?: string | undefined;
    SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER_JSON_RPC_ENDPOINT?: string | undefined;
    SETTLEMINT_HASURA?: string | undefined;
    SETTLEMINT_HASURA_ENDPOINT?: string | undefined;
    SETTLEMINT_HASURA_ADMIN_SECRET?: string | undefined;
    SETTLEMINT_HASURA_DATABASE_URL?: string | undefined;
    SETTLEMINT_THEGRAPH?: string | undefined;
    SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS?: unknown;
    SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH?: string | undefined;
    SETTLEMINT_PORTAL?: string | undefined;
    SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT?: string | undefined;
    SETTLEMINT_PORTAL_REST_ENDPOINT?: string | undefined;
    SETTLEMINT_HD_PRIVATE_KEY?: string | undefined;
    SETTLEMINT_ACCESSIBLE_PRIVATE_KEY?: string | undefined;
    SETTLEMINT_MINIO?: string | undefined;
    SETTLEMINT_MINIO_ENDPOINT?: string | undefined;
    SETTLEMINT_MINIO_ACCESS_KEY?: string | undefined;
    SETTLEMINT_MINIO_SECRET_KEY?: string | undefined;
    SETTLEMINT_IPFS?: string | undefined;
    SETTLEMINT_IPFS_API_ENDPOINT?: string | undefined;
    SETTLEMINT_IPFS_PINNING_ENDPOINT?: string | undefined;
    SETTLEMINT_IPFS_GATEWAY_ENDPOINT?: string | undefined;
    SETTLEMINT_CUSTOM_DEPLOYMENT?: string | undefined;
    SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT?: string | undefined;
    SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT?: string | undefined;
    SETTLEMINT_NEW_PROJECT_NAME?: string | undefined;
    SETTLEMINT_LOG_LEVEL?: "error" | "info" | "warn" | "debug" | "none" | undefined;
}>;
/**
 * Type definition for the partial environment variables schema.
 */
type DotEnvPartial = z.infer<typeof DotEnvSchemaPartial>;

/**
 * Loads environment variables from .env files.
 * To enable encryption with dotenvx (https://www.dotenvx.com/docs) run `bunx dotenvx encrypt`
 *
 * @param validateEnv - Whether to validate the environment variables against the schema
 * @param prod - Whether to load production environment variables
 * @param path - Optional path to the directory containing .env files. Defaults to process.cwd()
 * @returns A promise that resolves to the validated environment variables
 * @throws Will throw an error if validation fails and validateEnv is true
 * @example
 * import { loadEnv } from '@settlemint/sdk-utils/environment';
 *
 * // Load and validate environment variables
 * const env = await loadEnv(true, false);
 * console.log(env.SETTLEMINT_INSTANCE);
 *
 * // Load without validation
 * const rawEnv = await loadEnv(false, false);
 */
declare function loadEnv<T extends boolean = true>(validateEnv: T, prod: boolean, path?: string): Promise<T extends true ? DotEnv : DotEnvPartial>;

/**
 * Writes environment variables to .env files across a project or monorepo
 *
 * @param options - The options for writing the environment variables
 * @param options.prod - Whether to write production environment variables
 * @param options.env - The environment variables to write
 * @param options.secrets - Whether to write to .env.local files for secrets
 * @param options.cwd - The directory to start searching for the package.json file from (defaults to process.cwd())
 * @returns Promise that resolves when writing is complete
 * @throws Will throw an error if writing fails
 * @example
 * import { writeEnv } from '@settlemint/sdk-utils/environment';
 *
 * // Write development environment variables
 * await writeEnv({
 *   prod: false,
 *   env: {
 *     SETTLEMINT_INSTANCE: 'https://dev.example.com'
 *   },
 *   secrets: false
 * });
 *
 * // Write production secrets
 * await writeEnv({
 *   prod: true,
 *   env: {
 *     SETTLEMINT_ACCESS_TOKEN: 'secret-token'
 *   },
 *   secrets: true
 * });
 */
declare function writeEnv({ prod, env, secrets, cwd, }: {
    prod: boolean;
    env: Partial<DotEnv>;
    secrets: boolean;
    cwd?: string;
}): Promise<void>;

export { loadEnv, writeEnv };
