// src/validation/validate.ts
import { ZodError } from "zod";
function validate(schema, value) {
  try {
    return schema.parse(value);
  } catch (error) {
    if (error instanceof ZodError) {
      const formattedErrors = error.errors.map((err) => `- ${err.path.join(".")}: ${err.message}`).join("\n");
      throw new Error(`Validation error${error.errors.length > 1 ? "s" : ""}:
${formattedErrors}`);
    }
    throw error;
  }
}

// src/validation/access-token.schema.ts
import { z } from "zod";
var ApplicationAccessTokenSchema = z.string().regex(/^sm_aat_.*$/);
var PersonalAccessTokenSchema = z.string().regex(/^sm_pat_.*$/);
var AccessTokenSchema = z.string().regex(/^sm_pat_.*|sm_aat_.*$/);

// src/json.ts
function tryParseJson(value, defaultValue = null) {
  try {
    const parsed = JSON.parse(value);
    if (parsed === void 0 || parsed === null) {
      return defaultValue;
    }
    return parsed;
  } catch (err) {
    return defaultValue;
  }
}

// src/validation/dot-env.schema.ts
import { z as z4 } from "zod";

// src/validation/unique-name.schema.ts
import { z as z2 } from "zod";
var UniqueNameSchema = z2.string().regex(/^[a-z0-9-]+$/);

// src/validation/url.schema.ts
import { z as z3 } from "zod";
var UrlSchema = z3.string().url();
var UrlPathSchema = z3.string().regex(/^\/(?:[a-zA-Z0-9-_]+(?:\/[a-zA-Z0-9-_]+)*\/?)?$/, {
  message: "Invalid URL path format. Must start with '/' and can contain letters, numbers, hyphens, and underscores."
});
var UrlOrPathSchema = z3.union([UrlSchema, UrlPathSchema]);

// src/validation/dot-env.schema.ts
var DotEnvSchema = z4.object({
  /** Base URL of the SettleMint platform instance */
  SETTLEMINT_INSTANCE: UrlSchema.default("https://console.settlemint.com"),
  /** Application access token for authenticating with SettleMint services */
  SETTLEMINT_ACCESS_TOKEN: ApplicationAccessTokenSchema.optional(),
  /** @internal */
  SETTLEMINT_PERSONAL_ACCESS_TOKEN: PersonalAccessTokenSchema.optional(),
  /** Unique name of the workspace */
  SETTLEMINT_WORKSPACE: UniqueNameSchema.optional(),
  /** Unique name of the application */
  SETTLEMINT_APPLICATION: UniqueNameSchema.optional(),
  /** Unique name of the blockchain network */
  SETTLEMINT_BLOCKCHAIN_NETWORK: UniqueNameSchema.optional(),
  /** Chain ID of the blockchain network */
  SETTLEMINT_BLOCKCHAIN_NETWORK_CHAIN_ID: z4.string().optional(),
  /** Unique name of the blockchain node (should have a private key for signing transactions) */
  SETTLEMINT_BLOCKCHAIN_NODE: UniqueNameSchema.optional(),
  /** JSON RPC endpoint for the blockchain node */
  SETTLEMINT_BLOCKCHAIN_NODE_JSON_RPC_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the blockchain node or load balancer */
  SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER: UniqueNameSchema.optional(),
  /** JSON RPC endpoint for the blockchain node or load balancer */
  SETTLEMINT_BLOCKCHAIN_NODE_OR_LOAD_BALANCER_JSON_RPC_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the Hasura instance */
  SETTLEMINT_HASURA: UniqueNameSchema.optional(),
  /** Endpoint URL for the Hasura GraphQL API */
  SETTLEMINT_HASURA_ENDPOINT: UrlSchema.optional(),
  /** Admin secret for authenticating with Hasura */
  SETTLEMINT_HASURA_ADMIN_SECRET: z4.string().optional(),
  /** Database connection URL for Hasura */
  SETTLEMINT_HASURA_DATABASE_URL: z4.string().optional(),
  /** Unique name of The Graph instance */
  SETTLEMINT_THEGRAPH: UniqueNameSchema.optional(),
  /** Array of endpoint URLs for The Graph subgraphs */
  SETTLEMINT_THEGRAPH_SUBGRAPHS_ENDPOINTS: z4.preprocess(
    (value) => tryParseJson(value, []),
    z4.array(UrlSchema).optional()
  ),
  /** Default The Graph subgraph to use */
  SETTLEMINT_THEGRAPH_DEFAULT_SUBGRAPH: z4.string().optional(),
  /** Unique name of the Smart Contract Portal instance */
  SETTLEMINT_PORTAL: UniqueNameSchema.optional(),
  /** GraphQL endpoint URL for the Portal */
  SETTLEMINT_PORTAL_GRAPHQL_ENDPOINT: UrlSchema.optional(),
  /** REST endpoint URL for the Portal */
  SETTLEMINT_PORTAL_REST_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the HD private key */
  SETTLEMINT_HD_PRIVATE_KEY: UniqueNameSchema.optional(),
  /** Unique name of the accessible private key */
  SETTLEMINT_ACCESSIBLE_PRIVATE_KEY: UniqueNameSchema.optional(),
  /** Unique name of the MinIO instance */
  SETTLEMINT_MINIO: UniqueNameSchema.optional(),
  /** Endpoint URL for MinIO */
  SETTLEMINT_MINIO_ENDPOINT: UrlSchema.optional(),
  /** Access key for MinIO authentication */
  SETTLEMINT_MINIO_ACCESS_KEY: z4.string().optional(),
  /** Secret key for MinIO authentication */
  SETTLEMINT_MINIO_SECRET_KEY: z4.string().optional(),
  /** Unique name of the IPFS instance */
  SETTLEMINT_IPFS: UniqueNameSchema.optional(),
  /** API endpoint URL for IPFS */
  SETTLEMINT_IPFS_API_ENDPOINT: UrlSchema.optional(),
  /** Pinning service endpoint URL for IPFS */
  SETTLEMINT_IPFS_PINNING_ENDPOINT: UrlSchema.optional(),
  /** Gateway endpoint URL for IPFS */
  SETTLEMINT_IPFS_GATEWAY_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the custom deployment */
  SETTLEMINT_CUSTOM_DEPLOYMENT: UniqueNameSchema.optional(),
  /** Endpoint URL for the custom deployment */
  SETTLEMINT_CUSTOM_DEPLOYMENT_ENDPOINT: UrlSchema.optional(),
  /** Unique name of the Blockscout instance */
  SETTLEMINT_BLOCKSCOUT: UniqueNameSchema.optional(),
  /** GraphQL endpoint URL for Blockscout */
  SETTLEMINT_BLOCKSCOUT_GRAPHQL_ENDPOINT: UrlSchema.optional(),
  /** UI endpoint URL for Blockscout */
  SETTLEMINT_BLOCKSCOUT_UI_ENDPOINT: UrlSchema.optional(),
  /** Name of the new project being created */
  SETTLEMINT_NEW_PROJECT_NAME: z4.string().optional(),
  /** The log level to use */
  SETTLEMINT_LOG_LEVEL: z4.enum(["debug", "info", "warn", "error", "none"]).default("warn")
});
var DotEnvSchemaPartial = DotEnvSchema.partial();

// src/validation/id.schema.ts
import { z as z5 } from "zod";
var IdSchema = z5.union([
  z5.string().uuid(),
  // PostgreSQL UUID
  z5.string().regex(/^[0-9a-fA-F]{24}$/)
  // MongoDB ObjectID
]);
export {
  AccessTokenSchema,
  ApplicationAccessTokenSchema,
  DotEnvSchema,
  DotEnvSchemaPartial,
  IdSchema,
  PersonalAccessTokenSchema,
  UniqueNameSchema,
  UrlOrPathSchema,
  UrlPathSchema,
  UrlSchema,
  validate
};
//# sourceMappingURL=validation.mjs.map